@@ -172,8 +172,8 @@ class SaleOpportunity(ModelWorkflow, ModelSQL, ModelView):
         res = {
             'payment_term': False,
         }
-        if vals.get('party'):
-            party = party_obj.browse(vals['party'])
+        if values.get('party'):
+            party = party_obj.browse(values['party'])
             if party.payment_term:
                 res['payment_term'] = party.payment_term.id
         if not res['payment_term']:
